import org.ejml.simple.SimpleMatrix;

/**
 * Demonstrates how to solve a system of simultaneous 
 * equations using the EJML (www.emjl.org)
 * The three equations to solve are
 * 3x + y + z = 16
 * x + 2y + 9z = -7
 * 2x + 5y - z = 27
 * 
 * The correct solution is 
 * x = 5 ; y = 3 ; z = -2
 * 
 * Note the library use the double data type internally so we
 * pass the coefficients in arrays of type double.
 */
double[][] lhs = {
  { 3, 1, 1 }, 
  { 1, 2, 9 }, 
  { 2, 5, -1}
};
double [] rhs = { 16, -7, 27 };
float x, y, z;

public void setup() {
  // Solve the equations
  SimpleMatrix a = new SimpleMatrix(lhs);
  SimpleMatrix b = new SimpleMatrix(3, 1, true, rhs);
  a = a.invert().mult(b);
  x = (float) a.get(0);
  y = (float) a.get(1);
  z = (float) a.get(2);
  // Solution :-)
  System.out.println("Solution");
  System.out.println("x = " + x);
  System.out.println("y = " + y);
  System.out.println("z = " + z);
}
